@@ -5,4 +5,7 @@ from celery import task
 
 @task(ignore_result=True)
 def async_check(proxy, checker):
-    checker._check(proxy)
+    try:
+        checker._check(proxy)
+    except:
+        pass
